// component/adDialog/adDialog.js
var app = getApp()
const wxService = require('../../utils/wxService')
const utils = require('../../utils/util')
const envInfo = require('../../config/index').envInfo
const utilLink = require('../../utils/currentLinkRouter')

Component({
  /**
   * 组件的属性列表
   */
  properties: {
    pageInfo : {
      type: Object,
      value: {}
    },
    currentHasUserInfo: {
			type: Boolean,
			type: false
		},
  },

  observers:{
    pageInfo(val){
      this.handleAdDialog(val);
    }
  },

  /**
   * 组件的初始数据
   */
  data: {
    showDialog : false,
    imageUrl : '',
    needAuth : false,
    dialogInfo : {},
  },

  lifetimes:{
    attached(){
      // console.log(this.data.pageInfo)
    },
    created(){

    }
  },

  /**
   * 组件的方法列表
   */
  methods: {
    _getUserInfo(res = {}) {
			this.triggerEvent('getAuth', res);
		},
    //处理广告弹出层
    handleAdDialog(page){
      if(!page){
        this.data.showDialog = false;
        this.setData({
          showDialog : this.data.showDialog
        });
        return ;
      }

      if(!page.hasDialog){
        this.data.showDialog = false;
        this.setData({
          showDialog : this.data.showDialog
        });
        return ;
      }
      
      //有弹框
      this.data.showDialog = true;
      let dialogInfo = page.dialogInfo ? JSON.parse(page.dialogInfo) : null;
      if(dialogInfo){
        this.data.imageUrl = dialogInfo.imageUrl;
        if (dialogInfo.link) {
          if (dialogInfo.link.type == 2) {
            // 父组件 更新
            const urls = getCurrentPages()
            const currentPath = urls[0]
            // const currentPath = '/subPackage/page/pages/subPage/subPage'
            const pageId = dialogInfo.link.url
            dialogInfo.link.newPath = `/${currentPath.route}`
            dialogInfo.link.newPath = `/${currentPath.route}`
          }
        } else if (dialogInfo.row) {
          let newRow = JSON.parse(dialogInfo.row)
          if(Object.keys(newRow).length > 0){
            if (newRow.type == 8) {
              newRow.newPath = '/pages/productDetail/productDetail'
            } else if (newRow.type == 9) {
              newRow.newPath = '/subPackage/page/pages/categoryPro/categoryPro'
            }
  
            dialogInfo.row = newRow
          }
          else{
            delete dialogInfo.row;
          }
        }

        let checkUrl = '';

        if (dialogInfo.link) {
          checkUrl = dialogInfo.link.newPath ? dialogInfo.link.newPath : dialogInfo.link.url
        } else if (dialogInfo.row) {
          checkUrl = dialogInfo.row.newPath ? dialogInfo.row.newPath : dialogInfo.row.url
        }
        
        dialogInfo.needAuth = false;

        wxService.NoLoginPage(checkUrl).then(res => {
           if(checkUrl)  {
            dialogInfo.needAuth = res.needAuth;
            this.setData({
              dialogInfo : dialogInfo,
            });
           }
        });
      }
      this.setData({
        imageUrl : this.data.imageUrl,
        showDialog : this.data.showDialog && !this.todayHasDialog(),
        dialogInfo : dialogInfo,
      });

    },
    //预览
		preview(event) {
      if(!this.data.pageInfo.hasDialog){
        return ;
      }

      if(!this.data.dialogInfo.redirectId && !this.data.dialogInfo.row && !this.data.dialogInfo.link){
        return ;
      }

      this.onTapClose();
      utilLink.currentLinkRouter(event, this);
    },
    //设置弹出框本地弹出状态 //每天都弹出
    setLocalDialogStatus(){
      let currentRouter = getCurrentPages()[getCurrentPages().length - 1].route;
      let dialogInfo = wx.getStorageSync('dialogInfo');
      let key = `${currentRouter}_d_${this.getCurrentYearMonDay()}`;
      if(!dialogInfo){
        dialogInfo = {};
        dialogInfo[key] = true;
        wx.setStorageSync('dialogInfo',dialogInfo);
      }
      else{
        //先设置进去
        dialogInfo[key] = true;
        
        //获取今天的当前也的key
        let expiredAllKey = [];
        for(let k in dialogInfo){
          let expiredKey = k.split('_d_')[1];
          if(parseInt(expiredKey) < parseInt(this.getCurrentYearMonDay())){
            expiredAllKey.push(k);
          }
        }
        //移除今天一起的过期key
        expiredAllKey.forEach(item => {
          delete dialogInfo[item];
        });

        wx.setStorageSync('dialogInfo',dialogInfo);
      }
    },
    //获取今天是否已经弹出了
    todayHasDialog(){
      let currentRouter = getCurrentPages()[getCurrentPages().length - 1].route;
      let dialogInfo = wx.getStorageSync('dialogInfo');
      let key = `${currentRouter}_d_${this.getCurrentYearMonDay()}`;
      if(!dialogInfo){
        return false;
      }

      if(dialogInfo[key]){
        return true
      }

      return false;
    },
    //获取当前年月日
    getCurrentYearMonDay(){
      let da = new Date();
      return `${da.getFullYear()}${da.getMonth()}${da.getDate()}`;
    },
    //关闭
    onTapClose(){
      this.setLocalDialogStatus();
      this.setData({
        showDialog :false
      });
    }
  }
})
